/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2008, 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
  
 
#ifndef _GAME_CHOOSER_
#define _GAME_CHOOSER_
 
#include "../newtEngine/graphicOptions.h"
#include "gameChooserKeyboardOptions.h"
  
#include "../game.h"
#include "gameLauncher.h"

#include "../newtEngine/glUtil.h"
#include "../newtEngine/color.h"
#include "../newtEngine/material.h"
 
#include "../newtEngine/sky.h"
#include "../newtEngine/waterPlane.h"


#include "../variousEntities/rectangle.h"
#include "../variousEntities/polygon.h"
#include "../variousEntities/prism.h"
#include "../variousEntities/sphere.h"

#include "../variousEntities/cylinder.h"
#include "../variousEntities/torus.h"
#include "../variousEntities/partialSphere.h"
#include "../variousEntities/roundEdge.h"



const float EYE_HEIGHT = 100.;

const float PRISM_INNER_RADIUS = 200.;
const float PRISM_HEIGHT = 30.;
const float PRISM_Y_POS = 10.;

const float DIST_MAX_2 = 250000.;


class GameChooser : public NewtState {
	public:
		GameChooser();	
		~GameChooser();
	
		newtGame getSelectedLauncher();
		
		void initDisplayEnvironments();
		void createObjects();
		void createLights();
			
		void updateAnimations(double currentTime, double intervalTime);

		
		void quit();

		//keyboardEvent
		bool keyboardEvent(SDLKey key, double timeInterval);
		void move(Vector3 step);
		void launchGame();

		//mouse events
		void mouseMotion(int xOld, int yOld, int xNew, int yNew, bool left, bool middle, bool right);
		void leftClick(int x, int y);
		void rightClick(int x, int y);
		void middleClick(int x, int y);
		void mouseWheel(int w);		
			
	 private:
		std::vector<GameLauncher*> launchers;
		std::vector<LightPoint*> lightsLaunchers;
		newtGame selectedLauncher;
	
		Camera *camera;
		Sky *sky;
		WaterPlane *sea;

		LightDir *sun;
		LightSpot *spot;

		
		Material *materialFloor, *materialWall;
		//RectangleMesh *meshFloor;
		//Rectangle *floor;
		PolygonMesh *meshFloor;
		EntityWithPosition *floor;
				
		PrismWithPosition *prism;
		//Prism *prism;
};

#endif //_GAME_CHOOSER_
