/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2008, 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "entityWithValue.h"

/************************************************/
/*	EntityWithValue								*/
/************************************************/

EntityWithValue::EntityWithValue(Material *material, Mesh *mesh, int value, bool visible) :
	Entity(material, mesh, true), mValue(value) {
}
			   
EntityWithValue::~EntityWithValue() {	
}
	
int EntityWithValue::getValue() {
	return mValue;
}

void EntityWithValue::setValue(int value) {
	mValue = value;
}

/************************************************/
/*	EntityWithValueInLine						*/
/************************************************/

EntityWithValueInLine::EntityWithValueInLine(Material *material, Mesh *mesh, int value, int index, float interval, bool visible, Vector3 axis):
	EntityWithValue(material, mesh, value, visible), mIndex(index)
{
	position = interval * (float) mIndex * axis;
}

EntityWithValueInLine::~EntityWithValueInLine() {
}

void EntityWithValueInLine::applyTransformation() {
	glTranslatef (position.x, position.y, position.z);
}


/************************************************/
/*	EntityWithValueInPlane						*/
/************************************************/

EntityWithValueInPlane::EntityWithValueInPlane(Material *material, Mesh *mesh, int value, int index1, int index2, float interval, bool visible,
											 Vector3 axis1, Vector3 axis2):
	EntityWithValue(material, mesh, value, visible), mIndex1(index1), mIndex2(index2)
{
	position = interval * (float) mIndex1 * axis1 +
			   interval * (float) mIndex2 * axis2 ;
}

EntityWithValueInPlane::~EntityWithValueInPlane() {
}

void EntityWithValueInPlane::applyTransformation() {
	glTranslatef (position.x, position.y, position.z);
}


/************************************************/
/*	EntityWithValueInTab						*/
/************************************************/

EntityWithValueInTab::EntityWithValueInTab(Material *material, Mesh *mesh, int value, int index1, int index2, int index3, float interval, bool visible,
										   Vector3 axis1, Vector3 axis2, Vector3 axis3):
	EntityWithValue(material, mesh, value, visible), mIndex1(index1), mIndex2(index2), mIndex3(index3)
{
	position = interval * (float) mIndex1 * axis1 +
			   interval * (float) mIndex2 * axis2 +
			   interval * (float) mIndex3 * axis3 ;
}

EntityWithValueInTab::~EntityWithValueInTab() {
}

void EntityWithValueInTab::applyTransformation() {
	glTranslatef (position.x, position.y, position.z);
}





/************************************************/
/*	EntityWithValueInRing						*/
/************************************************/

EntityWithValueInRing::EntityWithValueInRing(Material *material, Mesh *mesh, int value, int index, float radius, float angleOffset, int nb, bool visible):
	EntityWithValue(material, mesh, value, visible), mIndex(index), mRadius(radius), mPhi(0.), mTheta(0.) {
	mAngle = (float) index / (float) nb * 360. + angleOffset;
}

EntityWithValueInRing::EntityWithValueInRing(Material *material, Mesh *mesh, int value, int index, float radius, float angleOffset, int nb, float theta, float phi, bool visible):
	EntityWithValue(material, mesh, value, visible), mIndex(index), mRadius(radius), mPhi(phi), mTheta(theta) {
	mAngle = (float) index / (float) nb * 360. + angleOffset;
}

EntityWithValueInRing::~EntityWithValueInRing() {
}

void EntityWithValueInRing::applyTransformation() {
	glRotatef (mAngle, 1.,0.,0.);
	glTranslatef(0.,0., mRadius);
	glRotatef(mPhi, 0., 0., 1.);
	glRotatef(mTheta, 1., 0., 0.);	
}

